@@ -6,8 +6,14 @@
 //!
 //!   [Stateless OpenPGP Command Line Interface]: https://datatracker.ietf.org/doc/draft-dkg-openpgp-stateless-cli/
 
+use sequoia_policy_config::ConfiguredStandardPolicy;
 use sequoia_sop::SQOP;
 
 fn main() {
-    sop::cli::main(&mut SQOP::default(), sop::cli::Variant::Verification);
+    let mut policy = ConfiguredStandardPolicy::default();
+    let _ = policy.parse_default_config();
+    let policy = policy.build();
+
+    sop::cli::main(&mut SQOP::with_policy(&policy),
+                   sop::cli::Variant::Verification);
 }
