@@ -3,19 +3,29 @@
 use sop::Result;
 
 /// Version information for SQOP.
-#[derive(Default)]
-pub struct Version {}
+pub struct Version {
+    name: &'static str,
+}
+
+impl Default for Version {
+    fn default() -> Self {
+        Self::with_name("sequoia-sop")
+    }
+}
+
+impl Version {
+    /// Returns a version with the name set to the given value.
+    pub fn with_name(name: &'static str) -> Self {
+        Version {
+            name,
+        }
+    }
+}
 
 impl sop::ops::Version<'_> for Version {
     fn frontend(&self) -> Result<sop::ops::VersionInfo> {
-	#[cfg(feature = "cliv")]
-	let name = "sqopv";
-
-	#[cfg(not(feature = "cliv"))]
-	let name = "sqop";
-
         Ok(sop::ops::VersionInfo {
-            name: name.into(),
+            name: self.name.into(),
             version: env!("CARGO_PKG_VERSION").into(),
         })
     }
